@@ -18,29 +18,27 @@
  */
 
 #include <sigc++/trackable.h>
-#include <iostream>
-
-SIGC_USING_STD(ostream)
-
-using namespace std;
 
 namespace sigc
 {
 
-trackable::trackable()
+trackable::trackable() noexcept
 : callback_list_(nullptr)
 {}
 
 /* Don't copy the notification list.
    The objects watching src don't need to be notified when the new object dies. */
-trackable::trackable(const trackable& /*src*/)
+trackable::trackable(const trackable& /*src*/) noexcept
 : callback_list_(nullptr)
 {}
 
-// Don't copy the notification list.
+// Don't move the notification list.
 // The objects watching src don't need to be notified when the new object dies.
 // They need to be notified now, because src probably becomes useless.
-trackable::trackable(trackable&& src) noexcept
+//
+// If trackable's move constructor is modified, check if Glib::Object's
+// move constructor should be modified similarly.
+trackable::trackable(trackable&& src)
 : callback_list_(nullptr)
 {
   src.notify_callbacks();
@@ -54,7 +52,7 @@ trackable& trackable::operator=(const trackable& src)
   return *this;
 }
 
-trackable& trackable::operator=(trackable&& src) noexcept
+trackable& trackable::operator=(trackable&& src)
 {
   if(this != &src)
   {
